@@ -56,10 +56,7 @@
 #include "xfpm-enum-types.h"
 #include "xfpm-notify.h"
 #include "xfpm-marshal.h"
-
-#ifndef _
-#define _(x) x
-#endif
+#include "xfpm-string.h"
 
 #define XFPM_BATTERY_GET_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE(o,XFPM_TYPE_BATTERY,XfpmBatteryPrivate))
 
@@ -107,8 +104,6 @@ static void xfpm_battery_show_critical_options(XfpmBattery *batt,
 											   XfpmBatteryType battery_type);
 static void xfpm_battery_handle_primary_critical(XfpmBattery *batt,
                                                 XfpmBatteryIcon *icon);
-static void xfpm_battery_handle_ups_critical(XfpmBattery *batt,
-                                             XfpmBatteryIcon *icon);                                                
 static void xfpm_battery_handle_critical_charge(XfpmBattery *batt,
                                                 XfpmBatteryIcon *icon);
                                                 
@@ -515,16 +510,16 @@ xfpm_battery_notify_cb (GObject *object,
 {
     XFPM_DEBUG("arg1->name=%s\n",arg1->name);
     
-    if (!strcmp(arg1->name,"show-tray-icon"))
+    if (!xfpm_strcmp(arg1->name,"show-tray-icon"))
     {
         xfpm_battery_refresh_tray_icon(XFPM_BATTERY(object));
     }
-    else if ( !strcmp(arg1->name,"critical-charge"))
+    else if ( !xfpm_strcmp(arg1->name,"critical-charge"))
     {
         xfpm_battery_refresh_critical_charge(XFPM_BATTERY(object));
     }
 #ifdef HAVE_LIBNOTIFY
-    else if ( !strcmp(arg1->name,"enable-notification"))
+    else if ( !xfpm_strcmp(arg1->name,"enable-notification"))
     {
         xfpm_battery_refresh_notification(XFPM_BATTERY(object));
     }    
@@ -621,7 +616,7 @@ xfpm_battery_handle_device_property_changed(XfpmHal *hal,const gchar *udi,
         {
             return;
         }
-        if ( !strcmp(key,"battery.charge_level.last_full") )
+        if ( !xfpm_strcmp(key,"battery.charge_level.last_full") )
         {
             GError *error = NULL;
             guint last_full = xfpm_hal_get_int_info(priv->hal,
@@ -637,9 +632,9 @@ xfpm_battery_handle_device_property_changed(XfpmHal *hal,const gchar *udi,
             return;
         }
 
-        if ( strcmp(key,"battery.charge_level.current")           &&
-             strcmp(key,"battery.rechargeable.is_charging")       &&
-             strcmp(key,"battery.rechargeable.is_discharging") )
+        if ( xfpm_strcmp(key,"battery.charge_level.current")           &&
+             xfpm_strcmp(key,"battery.rechargeable.is_charging")       &&
+             xfpm_strcmp(key,"battery.rechargeable.is_discharging") )
         {
             return;
         }
@@ -746,12 +741,12 @@ xfpm_battery_handle_device_property_changed(XfpmHal *hal,const gchar *udi,
 static void
 _do_critical_action(NotifyNotification *n,gchar *action,XfpmBattery *batt)
 {
-    if (!strcmp(action,"shutdown"))
+    if (!xfpm_strcmp(action,"shutdown"))
     {
         XFPM_DEBUG("Sending shutdown request\n");
         g_signal_emit(G_OBJECT(batt),signals[XFPM_ACTION_REQUEST],0,XFPM_DO_SHUTDOWN,TRUE);
     }
-    else if ( !strcmp(action,"hibernate"))
+    else if ( !xfpm_strcmp(action,"hibernate"))
     {
         XFPM_DEBUG("Sending hibernate request\n");
         g_signal_emit(G_OBJECT(batt),signals[XFPM_ACTION_REQUEST],0,XFPM_DO_HIBERNATE,TRUE);
@@ -854,10 +849,38 @@ xfpm_battery_handle_primary_critical(XfpmBattery *batt,XfpmBatteryIcon *icon)
     }
 }
 
-static void
-xfpm_battery_handle_ups_critical(XfpmBattery *batt,XfpmBatteryIcon *icon)
+static gboolean
+xfpm_battery_is_critical_charge(XfpmBattery *batt)
 {
-    xfpm_battery_show_critical_options(batt,icon,UPS);
+    XfpmBatteryPrivate *priv;
+    priv = XFPM_BATTERY_GET_PRIVATE(batt);
+    
+    if ( g_hash_table_size(priv->batteries ) == 1 ) return TRUE;
+    if ( g_hash_table_size(priv->batteries)  == 0 ) return FALSE;
+        
+    GList *icons_list;
+    int i=0;
+    icons_list = g_hash_table_get_values(priv->batteries);
+        
+    gboolean critical = FALSE;
+    
+    for ( i = 0 ; i < g_list_length(icons_list) ; i++ )
+    {
+	XfpmBatteryType type;
+	XfpmBatteryState state;
+	XfpmBatteryIcon *icon;
+        icon = g_list_nth_data(icons_list,i);
+	if ( icon )
+	{
+		g_object_get(G_OBJECT(icon),"battery-type", &type, "battery-state", &state, NULL);
+		if ( type != PRIMARY || type != UPS ) continue;
+		
+		if ( state == CRITICAL ) critical = TRUE;
+		else                     critical = FALSE;
+	}
+    }
+    
+    return critical;
 }
 
 static void
@@ -866,20 +889,17 @@ xfpm_battery_handle_critical_charge(XfpmBattery *batt,XfpmBatteryIcon *icon)
     XfpmBatteryType battery_type;
     g_object_get(G_OBJECT(icon),"battery-type",&battery_type,NULL);
     
-    if ( battery_type == PRIMARY )
+    if ( battery_type == PRIMARY || battery_type == UPS )
     {
-        xfpm_battery_handle_primary_critical(batt,icon);
-    }
-    else if ( battery_type == UPS )
-    {
-        xfpm_battery_handle_ups_critical(batt,icon);
+	if ( xfpm_battery_is_critical_charge(batt) )
+        	xfpm_battery_handle_primary_critical(batt,icon);
     }
 }
 
 static void
 xfpm_battery_state_change_cb(GObject *object,GParamSpec *arg1,gpointer data)
 {
-    if ( !strcmp(arg1->name,"battery-state") ) 
+    if ( !xfpm_strcmp(arg1->name,"battery-state") ) 
     {
         XfpmBatteryState state;
         XfpmBattery *batt = XFPM_BATTERY(data);
@@ -1004,25 +1024,25 @@ static void xfpm_battery_popup_tray_icon_menu(GtkStatusIcon *tray_icon,
 	
 	// Popup the menu
 	gtk_menu_popup(GTK_MENU(menu),NULL,NULL,
-		       NULL,NULL,button,activate_time);
+		       gtk_status_icon_position_menu,tray_icon,button,activate_time);
 }
 
 static XfpmBatteryType
 xfpm_battery_get_battery_type(const gchar *battery_type)
 {
-    if ( !strcmp("primary",battery_type) )
+    if ( !xfpm_strcmp("primary",battery_type) )
     {
         return PRIMARY;
     }
-    else if ( !strcmp("keyboard",battery_type) )
+    else if ( !xfpm_strcmp("keyboard",battery_type) )
     {
         return KEYBOARD;
     }
-    else if ( !strcmp("mouse",battery_type) ) 
+    else if ( !xfpm_strcmp("mouse",battery_type) ) 
     {
         return MOUSE;
     }
-    else if ( !strcmp("ups",battery_type) ) 
+    else if ( !xfpm_strcmp("ups",battery_type) ) 
     {
         return UPS; 
     }
