@@ -65,8 +65,8 @@
 #include "xfpm-lcd-brightness.h"
 #include "xfpm-popups.h"
 #include "xfpm-enum-types.h"
-#include "xfpm-settings.h"
 #include "xfpm-dbus-messages.h"
+#include "xfpm-string.h"
 
 #ifdef HAVE_LIBNOTIFY
 #include "xfpm-notify.h"
@@ -86,6 +86,9 @@ static void xfpm_driver_init        (XfpmDriver *drv);
 static void xfpm_driver_class_init  (XfpmDriverClass *klass);
 static void xfpm_driver_finalize    (GObject *object);
 
+static void xfpm_driver_dbus_class_init (XfpmDriverClass *klass);
+static void xfpm_driver_dbus_init       (XfpmDriver *manager);
+
 static void xfpm_driver_ac_adapter_state_changed_cb(XfpmAcAdapter *adapter,
                                                     gboolean present,
                                                     gboolean state_ok,
@@ -98,8 +101,6 @@ static void xfpm_driver_property_changed_cb(XfconfChannel *channel,
                                             GValue *value,
                                             XfpmDriver *drv);
                                             
-static gboolean xfpm_driver_show_options_dialog(XfpmDriver *drv);
-
 /* Function that receives events suspend/hibernate,shutdown for all
  * Xfce power manager components and syncronize them
  */
@@ -129,26 +130,19 @@ static void xfpm_driver_check(XfpmDriver *drv);
 
 static void xfpm_driver_load_all(XfpmDriver *drv);
 
-/* DBus message Filter and replies */
-static void xfpm_driver_send_reply(DBusConnection *conn,DBusMessage *mess);
-static DBusHandlerResult xfpm_driver_signal_filter
-    (DBusConnection *connection,DBusMessage *message,void *user_data);
-
-static guint32 socket_id = 0;
-
 #define XFPM_DRIVER_GET_PRIVATE(o) \
 (G_TYPE_INSTANCE_GET_PRIVATE((o),XFPM_TYPE_DRIVER,XfpmDriverPrivate))
 
 struct XfpmDriverPrivate 
 {
-    DBusConnection *conn;
+    DBusGConnection *bus;
     GMainLoop *loop;
+    XfconfChannel *channel;
     
     SystemFormFactor formfactor;
     
     guint8 power_management;
 
-	gboolean dialog_opened;
 #ifdef HAVE_LIBNOTIFY    
     gboolean show_power_management_error;
 #endif
@@ -159,7 +153,7 @@ struct XfpmDriverPrivate
     gboolean cpufreq_control;
     gboolean buttons_control;
     gboolean lcd_brightness_control;
-	gboolean nm_responding;
+    gboolean nm_responding;
     
     XfpmHal     *hal;
     XfpmCpu     *cpu;
@@ -184,6 +178,7 @@ xfpm_driver_class_init(XfpmDriverClass *klass)
     object_class->finalize = xfpm_driver_finalize;
     
     g_type_class_add_private(klass,sizeof(XfpmDriverPrivate));
+    
 }
 
 static void
@@ -192,16 +187,14 @@ xfpm_driver_init(XfpmDriver *drv)
     XfpmDriverPrivate *priv;
     priv = XFPM_DRIVER_GET_PRIVATE(drv);
 
-	priv->conn = NULL;
     priv->power_management = 0;
         
-    priv->dialog_opened = FALSE;
     priv->cpufreq_control = FALSE;
     priv->buttons_control = FALSE;
     priv->enable_power_save = FALSE;
     priv->lcd_brightness_control = FALSE;
     priv->accept_sleep_request = TRUE;
-	priv->nm_responding = FALSE;
+    priv->nm_responding = FALSE;
  
     priv->loop    = NULL;
     priv->cpu     = NULL;
@@ -252,9 +245,9 @@ xfpm_driver_finalize(GObject *object)
     {
         g_object_unref(drv->priv->lcd);
     }
-    if ( drv->priv->conn )
+    if ( drv->priv->bus )
     {
-        dbus_connection_unref(drv->priv->conn);
+        dbus_g_connection_unref(drv->priv->bus);
     }
     if ( drv->priv->loop )
     {
@@ -341,50 +334,6 @@ static void xfpm_driver_ac_adapter_state_changed_cb(XfpmAcAdapter *adapter,
     }
 }                                                    
 
-static void
-_dialog_response_cb(GtkDialog *dialog, gint response, XfpmDriver *drv)
-{
-    XfpmDriverPrivate *priv;
-    priv = XFPM_DRIVER_GET_PRIVATE(drv);
-    
-    priv->dialog_opened = FALSE;
-    
-    switch(response) 
-    {
-            case GTK_RESPONSE_HELP:
-				xfpm_help();
-                break;
-            default:
-                gtk_widget_destroy(GTK_WIDGET(dialog));
-                break;
-    }
-    
-}              
-
-static void
-_close_dialog_cb(GtkDialog *dialog,XfpmDriver *drv)
-{
-    gpointer data = 
-    g_object_get_data(G_OBJECT(drv),"conf-channel");
-    if ( data )
-    {
-        XfconfChannel *channel = (XfconfChannel *)data;
-        g_object_unref(channel);
-    }
-    
-}
-
-static void
-_close_plug_cb(GtkWidget *plug,GdkEvent *ev,XfpmDriver *drv)
-{
-	XfpmDriverPrivate *priv;
-	priv = XFPM_DRIVER_GET_PRIVATE(drv);
-	priv->dialog_opened = FALSE;
-	_close_dialog_cb(NULL,drv);
-	gtk_widget_destroy(plug);
-	
-}
-
 static void
 xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
                                 GValue *value,XfpmDriver *drv)
@@ -400,21 +349,21 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
     priv = XFPM_DRIVER_GET_PRIVATE(drv);
     
     
-    if ( !strcmp(property,CRITICAL_BATT_CFG) ) 
+    if ( !xfpm_strcmp(property,CRITICAL_BATT_CFG) ) 
     {
         guint val = g_value_get_uint(value);
         g_object_set(G_OBJECT(priv->batt),"critical-charge",val,NULL);
         return;
     }
     
-    if ( !strcmp(property,CRITICAL_BATT_ACTION_CFG) ) 
+    if ( !xfpm_strcmp(property,CRITICAL_BATT_ACTION_CFG) ) 
     {
         guint val = g_value_get_uint(value);
         g_object_set(G_OBJECT(priv->batt),"critical-action",val,NULL);
         return;
     }
     
-    if ( !strcmp(property,SHOW_TRAY_ICON_CFG) ) 
+    if ( !xfpm_strcmp(property,SHOW_TRAY_ICON_CFG) ) 
     {
         gboolean val = g_value_get_uint(value);
         g_object_set(G_OBJECT(priv->batt),"show-tray-icon",val,NULL);
@@ -423,20 +372,20 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
     
     if ( priv->cpufreq_control )
     {
-        if ( !strcmp(property,CPU_FREQ_SCALING_CFG) ) 
+        if ( !xfpm_strcmp(property,CPU_FREQ_SCALING_CFG) ) 
         {
             gboolean val = g_value_get_boolean(value);
             g_object_set(G_OBJECT(priv->cpu),"cpu-freq",val,NULL);
             return;
         }
         
-        if ( !strcmp(property,ON_AC_CPU_GOV_CFG) ) 
+        if ( !xfpm_strcmp(property,ON_AC_CPU_GOV_CFG) ) 
         {
             guint val = g_value_get_uint(value);
             g_object_set(G_OBJECT(priv->cpu),"on-ac-cpu-gov",val,NULL);
             return;
         }
-        if ( !strcmp(property,ON_BATT_CPU_GOV_CFG) ) 
+        if ( !xfpm_strcmp(property,ON_BATT_CPU_GOV_CFG) ) 
         {
             guint val = g_value_get_uint(value);
             g_object_set(G_OBJECT(priv->cpu),"on-batt-cpu-gov",val,NULL);
@@ -444,7 +393,7 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
         }
     }
 #ifdef HAVE_LIBNOTIFY    
-    if ( !strcmp(property,BATT_STATE_NOTIFICATION_CFG) ) 
+    if ( !xfpm_strcmp(property,BATT_STATE_NOTIFICATION_CFG) ) 
     {
         gboolean val = g_value_get_boolean(value);
         g_object_set(G_OBJECT(priv->batt),"enable-notification",val,NULL);
@@ -454,7 +403,7 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
 
     if ( priv->lcd_brightness_control )
     {
-        if ( !strcmp(property,LCD_BRIGHTNESS_CFG) )
+        if ( !xfpm_strcmp(property,LCD_BRIGHTNESS_CFG) )
         {
             gboolean val = g_value_get_boolean(value);
             g_object_set(G_OBJECT(priv->lcd),"brightness-enabled",val,NULL);
@@ -462,7 +411,7 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
         }
     }
 #ifdef HAVE_DPMS
-    if ( !strcmp(property,DPMS_ENABLE_CFG) ) 
+    if ( !xfpm_strcmp(property,DPMS_ENABLE_CFG) ) 
     {
         gboolean val = g_value_get_boolean(value);
         priv->dpms->dpms_enabled = val;
@@ -470,7 +419,7 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
         return;
     }
 
-    if ( !strcmp(property,ON_BATT_DPMS_TIMEOUTS_CFG) ) 
+    if ( !xfpm_strcmp(property,ON_BATT_DPMS_TIMEOUTS_CFG) ) 
     {
         GPtrArray *arr;
         gpointer data;
@@ -494,7 +443,7 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
         return;
     }
     
-    if ( !strcmp(property,ON_AC_DPMS_TIMEOUTS_CFG) ) 
+    if ( !xfpm_strcmp(property,ON_AC_DPMS_TIMEOUTS_CFG) ) 
     {
         GPtrArray *arr;
         gpointer data;
@@ -523,21 +472,21 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
 
     if ( priv->buttons_control )
     {
-        if ( !strcmp(property,LID_SWITCH_CFG) ) 
+        if ( !xfpm_strcmp(property,LID_SWITCH_CFG) ) 
         {
             guint val = g_value_get_uint(value);
             g_object_set(G_OBJECT(priv->bt),"lid-switch-action",val,NULL);
             return;
         }
         
-        if ( !strcmp(property,SLEEP_SWITCH_CFG) ) 
+        if ( !xfpm_strcmp(property,SLEEP_SWITCH_CFG) ) 
         {
             guint val = g_value_get_uint(value);
             g_object_set(G_OBJECT(priv->bt),"sleep-switch-action",val,NULL);
             return;
         }
         
-        if ( !strcmp(property,POWER_SWITCH_CFG) ) 
+        if ( !xfpm_strcmp(property,POWER_SWITCH_CFG) ) 
         {
             guint val = g_value_get_uint(value);
             g_object_set(G_OBJECT(priv->bt),"power-switch-action",val,NULL);
@@ -545,7 +494,7 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
         }
     }
     
-    if ( !strcmp(property,POWER_SAVE_CFG) )
+    if ( !xfpm_strcmp(property,POWER_SAVE_CFG) )
     {
         gboolean val = g_value_get_boolean(value);
         priv->enable_power_save = val;
@@ -554,78 +503,6 @@ xfpm_driver_property_changed_cb(XfconfChannel *channel,gchar *property,
     
 } 
 
-static gboolean
-xfpm_driver_show_options_dialog(XfpmDriver *drv)
-{
-    XfpmDriverPrivate *priv;
-    priv = XFPM_DRIVER_GET_PRIVATE(drv);
-    
-    if ( priv->dialog_opened )
-    {
-        return FALSE;
-    }
-
-    XfconfChannel *channel;
-    GtkWidget *dialog;
-
-    gboolean with_dpms;
-    
-    channel = xfconf_channel_new(XFPM_CHANNEL_CFG);
-    g_object_set_data(G_OBJECT(drv),"conf-channel",channel);
-    g_signal_connect(channel,"property-changed",
-                     G_CALLBACK(xfpm_driver_property_changed_cb),drv);
-
-    guint8 governors = 0;
-    if ( priv->cpufreq_control )
-    {    
-       governors = xfpm_cpu_get_available_governors(priv->cpu);
-    }
-
-#ifdef HAVE_DPMS
-    with_dpms = xfpm_dpms_capable(priv->dpms);
-#else
-    with_dpms = FALSE;
-#endif
-
-    guint8 switch_buttons = 0;
-    if ( priv->buttons_control )
-    {
-        switch_buttons = xfpm_button_get_available_buttons(priv->bt);
-    }
-    gboolean ups_found = xfpm_battery_ups_found(priv->batt);
-    
-    dialog = xfpm_settings_new(channel,
-                               priv->formfactor == SYSTEM_LAPTOP ? TRUE : FALSE,
-                               priv->power_management,
-                               with_dpms,
-                               governors,
-                               switch_buttons,
-                               priv->lcd_brightness_control,
-                               ups_found,
-                               socket_id);
-    if ( socket_id == 0 )
-    {
-    	xfce_gtk_window_center_on_monitor_with_pointer(GTK_WINDOW(dialog));
-    	gtk_window_set_modal(GTK_WINDOW(dialog), FALSE);
-    
-    	gdk_x11_window_set_user_time(dialog->window,gdk_x11_get_server_time (dialog->window));
-    
-    	g_signal_connect(dialog,"response",G_CALLBACK(_dialog_response_cb),drv);        
-    	g_signal_connect(dialog,"close",G_CALLBACK(_close_dialog_cb),drv);
-    	gtk_widget_show(dialog);
-    }	
-    else
-    {
-    	g_signal_connect(dialog,"delete-event",G_CALLBACK(_close_plug_cb),drv);
-		gdk_notify_startup_complete();
-	}
-    
-    priv->dialog_opened = TRUE;
-    socket_id = 0 ;
-    
-    return FALSE;
-}
-
 #ifdef HAVE_LIBNOTIFY
 static void
 xfpm_driver_report_sleep_errors(XfpmDriver *driver,const gchar *icon_name,const gchar *error)
@@ -844,19 +721,19 @@ _get_system_form_factor(XfpmDriverPrivate *priv)
                                             NULL);
     if (!factor ) return;
     
-    if ( !strcmp(factor,"laptop") )
+    if ( !xfpm_strcmp(factor,"laptop") )
     {
         priv->formfactor = SYSTEM_LAPTOP;
     }
-    else if ( !strcmp(factor,"desktop") )
+    else if ( !xfpm_strcmp(factor,"desktop") )
     {
         priv->formfactor = SYSTEM_DESKTOP;
     }
-    else if ( !strcmp(factor,"server") )
+    else if ( !xfpm_strcmp(factor,"server") )
     {
         priv->formfactor = SYSTEM_SERVER;
     }
-    else if ( !strcmp(factor,"unknown") )
+    else if ( !xfpm_strcmp(factor,"unknown") )
     {
         priv->formfactor = SYSTEM_UNKNOWN;
     }
@@ -887,7 +764,7 @@ xfpm_driver_load_config(XfpmDriver *drv)
 static void
 _disable_error(NotifyNotification *n,gchar *action,XfpmDriver *drv)
 {
-    if (strcmp(action,"confirmed")) return;
+    if (xfpm_strcmp(action,"confirmed")) return;
     
     XfconfChannel *channel;
     
@@ -1142,56 +1019,30 @@ xfpm_driver_load_all(XfpmDriver *drv)
 }
 
 static void
-xfpm_driver_send_reply(DBusConnection *conn,DBusMessage *mess)
+xfpm_driver_quit(XfpmDriver *drv)
 {
-    DBusMessage *reply;
-    reply = dbus_message_new_method_return(mess);
-    dbus_connection_send (conn, reply, NULL);
-    dbus_connection_flush (conn);
-    dbus_message_unref(reply);
-}
-
-static DBusHandlerResult xfpm_driver_signal_filter
-    (DBusConnection *connection,DBusMessage *message,void *user_data) 
-{
-    XfpmDriver *drv = XFPM_DRIVER(user_data);
-    XfpmDriverPrivate *priv;
-    priv = XFPM_DRIVER_GET_PRIVATE(drv);
+    XfpmDriverPrivate *priv = XFPM_DRIVER_GET_PRIVATE(drv);
     
-    if ( dbus_message_is_signal(message,"xfpm.power.manager","Customize" ) )
-    {
-        /* don't block the signal filter so show the configuration dialog in a
-         * timeout function otherwise xfce4-power-manager -q will have no effect*/
-        DBusError error;
-        dbus_error_init(&error);
-        dbus_message_get_args(message,&error,DBUS_TYPE_UINT32,&socket_id,DBUS_TYPE_INVALID);
-        if ( dbus_error_is_set(&error) )
-        {
-        	XFPM_DEBUG("Failed to get socket id: %s\n",error.message);
-        	dbus_error_free(&error);
-		}
-		XFPM_DEBUG("message customize received with socket_id=%d\n",socket_id);
-        g_timeout_add(100,(GSourceFunc)xfpm_driver_show_options_dialog,drv);
-        return DBUS_HANDLER_RESULT_HANDLED;
-    }    
+    xfpm_dbus_release_name(dbus_g_connection_get_connection(priv->bus), "org.xfce.PowerManager");
+    xfpm_dbus_release_name(dbus_g_connection_get_connection(priv->bus), "org.freedesktop.PowerManagement");
+    xfpm_dbus_release_name(dbus_g_connection_get_connection(priv->bus), "org.freedesktop.PowerManagement.Inhibit");
     
-    if ( dbus_message_is_signal(message,"xfpm.power.manager","Quit" ) )
-    {
-        XFPM_DEBUG("message quit received\n");
-        xfpm_driver_send_reply(connection,message);      
-        g_main_loop_quit(priv->loop);
-        g_object_unref(drv);
-        return DBUS_HANDLER_RESULT_HANDLED;
-    }    
-    
-    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+    g_main_loop_quit(priv->loop);
+    g_object_unref(drv);
 }
 
 XfpmDriver *
-xfpm_driver_new(void)
+xfpm_driver_new(DBusGConnection *bus)
 {
     XfpmDriver *driver = NULL;
     driver =  g_object_new(XFPM_TYPE_DRIVER,NULL);
+    
+    XfpmDriverPrivate *priv = XFPM_DRIVER_GET_PRIVATE(driver);
+    priv->bus = bus;
+    
+    xfpm_driver_dbus_class_init(XFPM_DRIVER_GET_CLASS(driver));
+    xfpm_driver_dbus_init(driver);
+    
     return driver;
 }
 
@@ -1206,23 +1057,6 @@ xfpm_driver_monitor (XfpmDriver *drv)
     
     priv->loop = g_main_loop_new(NULL,FALSE);
     
-    DBusError error;
-
-    dbus_error_init(&error);
-   
-    priv->conn = dbus_bus_get(DBUS_BUS_SESSION,&error);
-   
-    if (!priv->conn ) 
-    {
-       g_critical("Failed to connect to the DBus daemon: %s\n",error.message);
-       dbus_error_free(&error);
-       return FALSE;
-    }
-        
-    dbus_connection_setup_with_g_main(priv->conn,NULL);
-    dbus_bus_add_match(priv->conn, "type='signal',interface='xfpm.power.manager'",NULL);
-    dbus_connection_add_filter(priv->conn,xfpm_driver_signal_filter,drv,NULL);
-    
     priv->hal = xfpm_hal_new();
     if ( !xfpm_hal_is_connected(priv->hal) )  
     {
@@ -1230,6 +1064,7 @@ xfpm_driver_monitor (XfpmDriver *drv)
     }
     
     GError *g_error = NULL;
+    
     if ( !xfconf_init(&g_error) )
     {
         g_critical("xfconf init failed: %s using default settings\n",g_error->message);
@@ -1238,8 +1073,16 @@ xfpm_driver_monitor (XfpmDriver *drv)
         g_error_free(g_error);
         
     }
+    else
+    {
+	priv->channel = xfconf_channel_new(XFPM_CHANNEL_CFG);
+	g_signal_connect(G_OBJECT(priv->channel), "property-changed",
+			 G_CALLBACK(xfpm_driver_property_changed_cb), drv);
+    }
     
-    xfpm_dbus_register_name(priv->conn);
+    xfpm_dbus_register_name(dbus_g_connection_get_connection(priv->bus), "org.xfce.PowerManager");
+    xfpm_dbus_register_name(dbus_g_connection_get_connection(priv->bus), "org.freedesktop.PowerManagement");
+    xfpm_dbus_register_name(dbus_g_connection_get_connection(priv->bus), "org.freedesktop.PowerManagement.Inhibit");
     
     xfpm_driver_load_config(drv);    
     _get_system_form_factor(priv);
@@ -1249,13 +1092,137 @@ xfpm_driver_monitor (XfpmDriver *drv)
     xfpm_driver_load_all(drv);
     
     g_main_loop_run(priv->loop);
-   
-    xfpm_dbus_release_name(priv->conn);
-      
-    dbus_connection_remove_filter(priv->conn,xfpm_driver_signal_filter,NULL);
-    
-       
+
     xfconf_shutdown();
     
     return TRUE;
 }
+
+
+/*
+ * 
+ * DBus server implementation
+ * 
+ */
+
+static gboolean xfpm_driver_dbus_quit     (XfpmDriver *driver,
+					    GError **error);
+static gboolean xfpm_driver_dbus_get_conf(XfpmDriver *driver,
+					  gboolean   *OUT_system_laptop,
+					  gint       *OUT_power_management,
+					  gboolean   *OUT_with_dpms,
+					  gint       *OUT_governor,
+					  gint       *OUT_switch_buttons,
+					  gboolean   *OUT_brightness_control,
+					  gboolean   *OUT_ups_found,
+					  GError **error);
+static gboolean xfpm_driver_dbus_get_info (XfpmDriver *driver,
+					    gchar **OUT_name,
+					    gchar **OUT_version,
+					    gchar **OUT_vendor,
+					    GError **error);
+
+static gboolean  xfpm_driver_dbus_reload (XfpmDriver *driver, GError **error);
+
+#include "xfce-power-manager-dbus-server.h"
+
+static void
+xfpm_driver_dbus_class_init(XfpmDriverClass *klass)
+{
+     dbus_g_object_type_install_info(G_TYPE_FROM_CLASS(klass),
+				    &dbus_glib_xfpm_driver_object_info);
+}
+
+static void
+xfpm_driver_dbus_init(XfpmDriver *driver)
+{
+    XfpmDriverPrivate *priv;
+    priv = XFPM_DRIVER_GET_PRIVATE(driver);
+    dbus_g_connection_register_g_object(priv->bus,
+					"/org/xfce/PowerManager",
+					G_OBJECT(driver));
+}
+
+static gboolean
+xfpm_driver_dbus_quit(XfpmDriver *driver, GError **error)
+{
+    XFPM_DEBUG("Quit message received\n");
+    
+    xfpm_driver_quit(driver);
+    
+    return TRUE;
+}
+
+static gboolean
+xfpm_driver_dbus_get_conf(XfpmDriver *driver,
+			  gboolean   *OUT_system_laptop,
+			  gint       *OUT_power_management,
+			  gboolean   *OUT_with_dpms,
+			  gint       *OUT_governor,
+			  gint       *OUT_switch_buttons,
+			  gboolean   *OUT_brightness_control,
+			  gboolean   *OUT_ups_found,
+			  GError **error)
+{
+    XFPM_DEBUG("Get info message received\n");
+    XfpmDriverPrivate *priv = XFPM_DRIVER_GET_PRIVATE(driver);
+    
+    gboolean with_dpms;
+    
+    guint8 governors = 0;
+    if ( priv->cpufreq_control )
+    {    
+       governors = xfpm_cpu_get_available_governors(priv->cpu);
+    }
+
+#ifdef HAVE_DPMS
+    with_dpms = xfpm_dpms_capable(priv->dpms);
+#else
+    with_dpms = FALSE;
+#endif
+
+    guint8 switch_buttons = 0;
+    if ( priv->buttons_control )
+    {
+        switch_buttons = xfpm_button_get_available_buttons(priv->bt);
+    }
+    gboolean ups_found = xfpm_battery_ups_found(priv->batt);
+    
+    *OUT_system_laptop      = priv->formfactor == SYSTEM_LAPTOP ? TRUE : FALSE;
+    *OUT_power_management   = priv->power_management;
+    *OUT_with_dpms          = with_dpms;
+    *OUT_governor           = governors;
+    *OUT_switch_buttons     = switch_buttons;
+    *OUT_brightness_control = priv->lcd_brightness_control;
+    *OUT_ups_found          = ups_found;
+			       
+    return TRUE;
+}
+
+static gboolean 
+xfpm_driver_dbus_get_info (XfpmDriver *driver,
+			    gchar **OUT_name,
+			    gchar **OUT_version,
+			    gchar **OUT_vendor,
+			    GError **error)
+{
+    
+    *OUT_name    = g_strdup(PACKAGE);
+    *OUT_version = g_strdup(VERSION);
+    *OUT_vendor  = g_strdup("Xfce-goodies");
+    
+    return TRUE;
+}
+
+static gboolean 
+xfpm_driver_dbus_reload (XfpmDriver *driver, GError **error)
+{
+    XFPM_DEBUG("Reload message received\n");
+    
+    xfpm_driver_quit (driver);
+    /*Stupid, but the way 0.6 is is hard to have a clean reload*/
+    g_spawn_command_line_async ("xfce4-power-manager", NULL);
+    
+    
+    return TRUE;
+}
