@@ -1108,7 +1108,7 @@ _cursor_changed_cb(GtkIconView *view,gpointer data)
 }
 
 static GtkWidget *
-xfpm_settings_tree_view(gboolean is_laptop,gboolean ups,guint8 govs)
+xfpm_settings_tree_view(gboolean is_laptop,gboolean ups,guint8 govs,gboolean lcd,gboolean switch_buttons)
 {
     GdkPixbuf *pix;
     GtkWidget *view;
@@ -1116,6 +1116,7 @@ xfpm_settings_tree_view(gboolean is_laptop,gboolean ups,guint8 govs)
     GtkTreeIter iter;
     GtkTreeViewColumn *col;
     GtkCellRenderer *renderer;
+    gint i = 0;
 
     list_store = gtk_list_store_new(3,GDK_TYPE_PIXBUF,G_TYPE_STRING,G_TYPE_INT);
 
@@ -1141,13 +1142,14 @@ xfpm_settings_tree_view(gboolean is_laptop,gboolean ups,guint8 govs)
 		gtk_list_store_append(list_store,&iter);
 		if ( pix )
 		{
-			gtk_list_store_set(list_store,&iter,0,pix,1,_("CPU settings"),2,0,-1);
+			gtk_list_store_set(list_store,&iter,0,pix,1,_("CPU settings"),2,i,-1);
 			g_object_unref(pix);
 		}
 		else
 		{
-			gtk_list_store_set(list_store,&iter,1,_("CPU settings"),2,0,-1);
+			gtk_list_store_set(list_store,&iter,1,_("CPU settings"),2,i,-1);
 		}
+		i++;
 	}
     
     /// Battery Settings
@@ -1157,46 +1159,57 @@ xfpm_settings_tree_view(gboolean is_laptop,gboolean ups,guint8 govs)
         gtk_list_store_append(list_store,&iter);
         if ( pix )
         {
-            gtk_list_store_set(list_store,&iter,0,pix,1,_("Battery settings"),2,1,-1);
+            gtk_list_store_set(list_store,&iter,0,pix,1,_("Battery settings"),2,i,-1);
             g_object_unref(pix);
         }
         else
         {
-            gtk_list_store_set(list_store,&iter,1,_("Battery settings"),2,1,-1);
+            gtk_list_store_set(list_store,&iter,1,_("Battery settings"),2,i,-1);
         }
+        i++;
    }
 
     /// Keyboard Settings
-    if ( is_laptop )
+    if ( switch_buttons)
     {
         pix = xfpm_load_icon("keyboard",38);
         gtk_list_store_append(list_store,&iter);
         if ( pix )
         {
-            gtk_list_store_set(list_store,&iter,0,pix,1,_("Shortcuts"),2,2,-1);
+            gtk_list_store_set(list_store,&iter,0,pix,1,_("Shortcuts"),2,i,-1);
             g_object_unref(pix);
         }
         else
         {
-            gtk_list_store_set(list_store,&iter,1,_("Shortcuts"),2,2,-1);
+            gtk_list_store_set(list_store,&iter,1,_("Shortcuts"),2,i,-1);
         } 
+        i++;
     }
     
     /// Dpms settings
-#ifdef HAVE_DPMS    
-    pix = xfpm_load_icon("display",38);      
-    gtk_list_store_append(list_store,&iter);
-    if ( pix ) 
+    gboolean show_monitor_settings = FALSE;
+#ifdef HAVE_DPMS
+    show_monitor_settings = TRUE;
+#else
+    if ( lcd )
+    show_monitor_settings = TRUE;
+#endif    
+    
+    if ( show_monitor_settings )
     {
-        gtk_list_store_set(list_store,&iter,0,pix,1,_("Monitor Settings"),2,3,-1);
-        g_object_unref(pix);
+        pix = xfpm_load_icon("display",38);      
+        gtk_list_store_append(list_store,&iter);
+        if ( pix ) 
+        {
+            gtk_list_store_set(list_store,&iter,0,pix,1,_("Monitor Settings"),2,i,-1);
+            g_object_unref(pix);
+        }
+        else
+        {
+            gtk_list_store_set(list_store,&iter,1,_("Monitor Settings"),2,i,-1);
+        }
+        i++;
     }
-    else
-    {
-        gtk_list_store_set(list_store,&iter,1,_("Monitor Settings"),2,3,-1);
-    }
-#endif
-
     GtkTreeSelection *sel;
     GtkTreePath *path;
 
@@ -1217,8 +1230,7 @@ xfpm_settings_new(XfconfChannel *channel,
                   guint8 govs,
                   guint8 switch_buttons,
                   gboolean lcd,
-                  gboolean ups_found,
-                  guint32 socket_id)
+                  gboolean ups_found)
 {
     GtkWidget *Dialog;  /* Main dialog window */
     GtkWidget *mainbox; /* Box to get (Dialog)->vbox */
@@ -1227,7 +1239,7 @@ xfpm_settings_new(XfconfChannel *channel,
     GtkWidget *view;
     GtkWidget *allbox;
     GtkWidget *frame,*align;
-  
+    
     Dialog = xfce_titled_dialog_new_with_buttons(_("Power Manager Preferences"),
                                                     NULL,
                                                     GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -1265,10 +1277,10 @@ xfpm_settings_new(XfconfChannel *channel,
 
     gtk_box_pack_start (GTK_BOX (allbox), frame, TRUE, TRUE, SPACING);
 	
-    view = xfpm_settings_tree_view(is_laptop,ups_found,govs);
+    view = xfpm_settings_tree_view(is_laptop,ups_found,govs,lcd,switch_buttons);
 
 #ifndef HAVE_DPMS	
-	if ( is_laptop || ups_found || govs )
+	if ( is_laptop || ups_found || govs || switch_buttons )
 	{
 #endif
 		gtk_box_pack_start (GTK_BOX(table), view, FALSE, FALSE, SPACING);
@@ -1288,6 +1300,7 @@ xfpm_settings_new(XfconfChannel *channel,
 	}
 
     /// Battery settings
+    
 	if ( is_laptop || ups )
 	{
 		box = xfpm_settings_battery(channel,power_management,ups);
@@ -1301,24 +1314,11 @@ xfpm_settings_new(XfconfChannel *channel,
 		gtk_notebook_append_page(GTK_NOTEBOOK(nt),box,NULL); 
 	}
     
-    /// Dpms settings && LCD brightness settings DPMS existence is checked above
-#ifdef HAVE_DPMS	
+    /// Dpms & LCD brightness settings
+	
     box = xfpm_settings_monitor(channel,is_laptop,dpms_capable,lcd,ups);
     gtk_notebook_append_page(GTK_NOTEBOOK(nt),box,NULL);
-#else
-	if ( lcd )
-	{
-		box = xfpm_settings_monitor(channel,is_laptop,dpms_capable,lcd,ups);
-		gtk_notebook_append_page(GTK_NOTEBOOK(nt),box,NULL);
-	}
-#endif	
 
-	GtkWidget *plug;    
-    if ( socket_id != 0 )
-    {
-		plug = gtk_plug_new(socket_id);
-    	gtk_widget_show (plug);
-    	gtk_widget_reparent(allbox,plug);
-	}
-    return socket_id == 0 ? Dialog : plug ;
+
+    return Dialog;
 }
